@@ -872,7 +872,7 @@ sub GetParametersFromRules {
 ##      if ( defined ($Q = GetOperationParameter($line, "Q", "[^\\Q]*Q([0-9]*)" )) ) { 
 ##  Hmmm, I'm not really sure why I once placed the '\\' here, but now it is not good any more
         $Q = GetOperationParameter($line, "Q", "[^Q]*Q([0-9]*)" ) ;
-	if ( /{(\w*\.jpe?g)}/ ) {
+	if ( /{([^{}]*\.jpe?g)}/ ) {
 	    $WikiPediaLink = $1 ;
 	} else {
 	    $WikiPediaLink = "" ;
